# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class CaptionCharacterEncoding(Enum):
    ANSI_X3_4_1968 = "ANSI_X3.4-1968"
    ANSI_X3_4_1986 = "ANSI_X3.4-1986"
    ARABIC = "ARABIC"
    ARMSCII_8 = "ARMSCII-8"
    ASCII = "ASCII"
    ASMO_708 = "ASMO-708"
    BIG_5 = "BIG-5"
    BIG_FIVE = "BIG-FIVE"
    BIG5 = "BIG5"
    BIG5_HKSCS = "BIG5-HKSCS"
    BIG5_HKSCS_1999 = "BIG5-HKSCS:1999"
    BIG5_HKSCS_2001 = "BIG5-HKSCS:2001"
    BIG5_HKSCS_2004 = "BIG5-HKSCS:2004"
    BIG5_HKSCS_2008 = "BIG5-HKSCS:2008"
    BIG5HKSCS = "BIG5HKSCS"
    BIGFIVE = "BIGFIVE"
    C99 = "C99"
    CHAR = "CHAR"
    CHINESE = "CHINESE"
    CN = "CN"
    CN_BIG5 = "CN-BIG5"
    CN_GB = "CN-GB"
    CN_GB_ISOIR165 = "CN-GB-ISOIR165"
    CP1131 = "CP1131"
    CP1133 = "CP1133"
    CP1250 = "CP1250"
    CP1251 = "CP1251"
    CP1252 = "CP1252"
    CP1253 = "CP1253"
    CP1254 = "CP1254"
    CP1255 = "CP1255"
    CP1256 = "CP1256"
    CP1257 = "CP1257"
    CP1258 = "CP1258"
    CP1361 = "CP1361"
    CP154 = "CP154"
    CP367 = "CP367"
    CP819 = "CP819"
    CP850 = "CP850"
    CP862 = "CP862"
    CP866 = "CP866"
    CP874 = "CP874"
    CP932 = "CP932"
    CP936 = "CP936"
    CP949 = "CP949"
    CP950 = "CP950"
    CSASCII = "CSASCII"
    CSBIG5 = "CSBIG5"
    CSEUCKR = "CSEUCKR"
    CSEUCPKDFMTJAPANESE = "CSEUCPKDFMTJAPANESE"
    CSEUCTW = "CSEUCTW"
    CSGB2312 = "CSGB2312"
    CSHALFWIDTHKATAKANA = "CSHALFWIDTHKATAKANA"
    CSHPROMAN8 = "CSHPROMAN8"
    CSIBM866 = "CSIBM866"
    CSISO14JISC6220RO = "CSISO14JISC6220RO"
    CSISO159JISX02121990 = "CSISO159JISX02121990"
    CSISO2022CN = "CSISO2022CN"
    CSISO2022JP = "CSISO2022JP"
    CSISO2022JP2 = "CSISO2022JP2"
    CSISO2022KR = "CSISO2022KR"
    CSISO57GB1988 = "CSISO57GB1988"
    CSISO58GB231280 = "CSISO58GB231280"
    CSISO87JISX0208 = "CSISO87JISX0208"
    CSISOLATIN1 = "CSISOLATIN1"
    CSISOLATIN2 = "CSISOLATIN2"
    CSISOLATIN3 = "CSISOLATIN3"
    CSISOLATIN4 = "CSISOLATIN4"
    CSISOLATIN5 = "CSISOLATIN5"
    CSISOLATIN6 = "CSISOLATIN6"
    CSISOLATINARABIC = "CSISOLATINARABIC"
    CSISOLATINCYRILLIC = "CSISOLATINCYRILLIC"
    CSISOLATINGREEK = "CSISOLATINGREEK"
    CSISOLATINHEBREW = "CSISOLATINHEBREW"
    CSKOI8R = "CSKOI8R"
    CSKSC56011987 = "CSKSC56011987"
    CSKZ1048 = "CSKZ1048"
    CSMACINTOSH = "CSMACINTOSH"
    CSPC850MULTILINGUAL = "CSPC850MULTILINGUAL"
    CSPC862LATINHEBREW = "CSPC862LATINHEBREW"
    CSPTCP154 = "CSPTCP154"
    CSSHIFTJIS = "CSSHIFTJIS"
    CSUCS4 = "CSUCS4"
    CSUNICODE = "CSUNICODE"
    CSUNICODE11 = "CSUNICODE11"
    CSUNICODE11UTF7 = "CSUNICODE11UTF7"
    CSVISCII = "CSVISCII"
    CYRILLIC = "CYRILLIC"
    CYRILLIC_ASIAN = "CYRILLIC-ASIAN"
    ECMA_114 = "ECMA-114"
    ECMA_118 = "ECMA-118"
    ELOT_928 = "ELOT_928"
    EUC_CN = "EUC-CN"
    EUC_JP = "EUC-JP"
    EUC_KR = "EUC-KR"
    EUC_TW = "EUC-TW"
    EUCCN = "EUCCN"
    EUCJP = "EUCJP"
    EUCKR = "EUCKR"
    EUCTW = "EUCTW"
    EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE = "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE"
    GB_1988_80 = "GB_1988-80"
    GB_2312_80 = "GB_2312-80"
    GB18030 = "GB18030"
    GB2312 = "GB2312"
    GBK = "GBK"
    GEORGIAN_ACADEMY = "GEORGIAN-ACADEMY"
    GEORGIAN_PS = "GEORGIAN-PS"
    GREEK = "GREEK"
    GREEK8 = "GREEK8"
    HEBREW = "HEBREW"
    HP_ROMAN8 = "HP-ROMAN8"
    HZ = "HZ"
    HZ_GB_2312 = "HZ-GB-2312"
    IBM_CP1133 = "IBM-CP1133"
    IBM367 = "IBM367"
    IBM819 = "IBM819"
    IBM850 = "IBM850"
    IBM862 = "IBM862"
    IBM866 = "IBM866"
    ISO_10646_UCS_2 = "ISO-10646-UCS-2"
    ISO_10646_UCS_4 = "ISO-10646-UCS-4"
    ISO_2022_CN = "ISO-2022-CN"
    ISO_2022_CN_EXT = "ISO-2022-CN-EXT"
    ISO_2022_JP = "ISO-2022-JP"
    ISO_2022_JP_1 = "ISO-2022-JP-1"
    ISO_2022_JP_2 = "ISO-2022-JP-2"
    ISO_2022_KR = "ISO-2022-KR"
    ISO_8859_1 = "ISO-8859-1"
    ISO_8859_10 = "ISO-8859-10"
    ISO_8859_11 = "ISO-8859-11"
    ISO_8859_13 = "ISO-8859-13"
    ISO_8859_14 = "ISO-8859-14"
    ISO_8859_15 = "ISO-8859-15"
    ISO_8859_16 = "ISO-8859-16"
    ISO_8859_2 = "ISO-8859-2"
    ISO_8859_3 = "ISO-8859-3"
    ISO_8859_4 = "ISO-8859-4"
    ISO_8859_5 = "ISO-8859-5"
    ISO_8859_6 = "ISO-8859-6"
    ISO_8859_7 = "ISO-8859-7"
    ISO_8859_8 = "ISO-8859-8"
    ISO_8859_9 = "ISO-8859-9"
    ISO_CELTIC = "ISO-CELTIC"
    ISO_IR_100 = "ISO-IR-100"
    ISO_IR_101 = "ISO-IR-101"
    ISO_IR_109 = "ISO-IR-109"
    ISO_IR_110 = "ISO-IR-110"
    ISO_IR_126 = "ISO-IR-126"
    ISO_IR_127 = "ISO-IR-127"
    ISO_IR_138 = "ISO-IR-138"
    ISO_IR_14 = "ISO-IR-14"
    ISO_IR_144 = "ISO-IR-144"
    ISO_IR_148 = "ISO-IR-148"
    ISO_IR_149 = "ISO-IR-149"
    ISO_IR_157 = "ISO-IR-157"
    ISO_IR_159 = "ISO-IR-159"
    ISO_IR_165 = "ISO-IR-165"
    ISO_IR_166 = "ISO-IR-166"
    ISO_IR_179 = "ISO-IR-179"
    ISO_IR_199 = "ISO-IR-199"
    ISO_IR_203 = "ISO-IR-203"
    ISO_IR_226 = "ISO-IR-226"
    ISO_IR_57 = "ISO-IR-57"
    ISO_IR_58 = "ISO-IR-58"
    ISO_IR_6 = "ISO-IR-6"
    ISO_IR_87 = "ISO-IR-87"
    ISO_646_IRV_1991 = "ISO_646.IRV:1991"
    ISO_8859_1_1987 = "ISO_8859-1:1987"
    ISO_8859_10_1992 = "ISO_8859-10:1992"
    ISO_8859_14_1998 = "ISO_8859-14:1998"
    ISO_8859_15_1998 = "ISO_8859-15:1998"
    ISO_8859_16_2001 = "ISO_8859-16:2001"
    ISO_8859_2_1987 = "ISO_8859-2:1987"
    ISO_8859_3_1988 = "ISO_8859-3:1988"
    ISO_8859_4_1988 = "ISO_8859-4:1988"
    ISO_8859_5_1988 = "ISO_8859-5:1988"
    ISO_8859_6_1987 = "ISO_8859-6:1987"
    ISO_8859_7_1987 = "ISO_8859-7:1987"
    ISO_8859_7_2003 = "ISO_8859-7:2003"
    ISO_8859_8_1988 = "ISO_8859-8:1988"
    ISO_8859_9_1989 = "ISO_8859-9:1989"
    ISO646_CN = "ISO646-CN"
    ISO646_JP = "ISO646-JP"
    ISO646_US = "ISO646-US"
    ISO8859_1 = "ISO8859-1"
    ISO8859_10 = "ISO8859-10"
    ISO8859_11 = "ISO8859-11"
    ISO8859_13 = "ISO8859-13"
    ISO8859_14 = "ISO8859-14"
    ISO8859_15 = "ISO8859-15"
    ISO8859_16 = "ISO8859-16"
    ISO8859_2 = "ISO8859-2"
    ISO8859_3 = "ISO8859-3"
    ISO8859_4 = "ISO8859-4"
    ISO8859_5 = "ISO8859-5"
    ISO8859_6 = "ISO8859-6"
    ISO8859_7 = "ISO8859-7"
    ISO8859_8 = "ISO8859-8"
    ISO8859_9 = "ISO8859-9"
    JAVA = "JAVA"
    JIS_C6220_1969_RO = "JIS_C6220-1969-RO"
    JIS_C6226_1983 = "JIS_C6226-1983"
    JIS_X0201 = "JIS_X0201"
    JIS_X0208 = "JIS_X0208"
    JIS_X0208_1983 = "JIS_X0208-1983"
    JIS_X0208_1990 = "JIS_X0208-1990"
    JIS_X0212 = "JIS_X0212"
    JIS_X0212_1990 = "JIS_X0212-1990"
    JIS_X0212_1990_0 = "JIS_X0212.1990-0"
    JIS0208 = "JIS0208"
    JISX0201_1976 = "JISX0201-1976"
    JOHAB = "JOHAB"
    JP = "JP"
    KOI8_R = "KOI8-R"
    KOI8_RU = "KOI8-RU"
    KOI8_T = "KOI8-T"
    KOI8_U = "KOI8-U"
    KOREAN = "KOREAN"
    KS_C_5601_1987 = "KS_C_5601-1987"
    KS_C_5601_1989 = "KS_C_5601-1989"
    KSC_5601 = "KSC_5601"
    KZ_1048 = "KZ-1048"
    L1 = "L1"
    L10 = "L10"
    L2 = "L2"
    L3 = "L3"
    L4 = "L4"
    L5 = "L5"
    L6 = "L6"
    L7 = "L7"
    L8 = "L8"
    LATIN_9 = "LATIN-9"
    LATIN1 = "LATIN1"
    LATIN10 = "LATIN10"
    LATIN2 = "LATIN2"
    LATIN3 = "LATIN3"
    LATIN4 = "LATIN4"
    LATIN5 = "LATIN5"
    LATIN6 = "LATIN6"
    LATIN7 = "LATIN7"
    LATIN8 = "LATIN8"
    MAC = "MAC"
    MACARABIC = "MACARABIC"
    MACCENTRALEUROPE = "MACCENTRALEUROPE"
    MACCROATIAN = "MACCROATIAN"
    MACCYRILLIC = "MACCYRILLIC"
    MACGREEK = "MACGREEK"
    MACHEBREW = "MACHEBREW"
    MACICELAND = "MACICELAND"
    MACINTOSH = "MACINTOSH"
    MACROMAN = "MACROMAN"
    MACROMANIA = "MACROMANIA"
    MACTHAI = "MACTHAI"
    MACTURKISH = "MACTURKISH"
    MACUKRAINE = "MACUKRAINE"
    MS_ANSI = "MS-ANSI"
    MS_ARAB = "MS-ARAB"
    MS_CYRL = "MS-CYRL"
    MS_EE = "MS-EE"
    MS_GREEK = "MS-GREEK"
    MS_HEBR = "MS-HEBR"
    MS_TURK = "MS-TURK"
    MS_KANJI = "MS_KANJI"
    MS936 = "MS936"
    MULELAO_1 = "MULELAO-1"
    NEXTSTEP = "NEXTSTEP"
    PT154 = "PT154"
    PTCP154 = "PTCP154"
    R8 = "R8"
    RK1048 = "RK1048"
    ROMAN8 = "ROMAN8"
    SHIFT_JIS = "SHIFT-JIS"
    SJIS = "SJIS"
    STRK1048_2002 = "STRK1048-2002"
    TCVN = "TCVN"
    TCVN_5712 = "TCVN-5712"
    TCVN5712_1 = "TCVN5712-1"
    TCVN5712_1_1993 = "TCVN5712-1:1993"
    TIS_620 = "TIS-620"
    TIS620 = "TIS620"
    TIS620_0 = "TIS620-0"
    TIS620_2529_1 = "TIS620.2529-1"
    TIS620_2533_0 = "TIS620.2533-0"
    TIS620_2533_1 = "TIS620.2533-1"
    UCS_2 = "UCS-2"
    UCS_2_INTERNAL = "UCS-2-INTERNAL"
    UCS_2_SWAPPED = "UCS-2-SWAPPED"
    UCS_2BE = "UCS-2BE"
    UCS_2LE = "UCS-2LE"
    UCS_4 = "UCS-4"
    UCS_4_INTERNAL = "UCS-4-INTERNAL"
    UCS_4_SWAPPED = "UCS-4-SWAPPED"
    UCS_4BE = "UCS-4BE"
    UCS_4LE = "UCS-4LE"
    UHC = "UHC"
    UNICODE_1_1 = "UNICODE-1-1"
    UNICODE_1_1_UTF_7 = "UNICODE-1-1-UTF-7"
    UNICODEBIG = "UNICODEBIG"
    UNICODELITTLE = "UNICODELITTLE"
    US = "US"
    US_ASCII = "US-ASCII"
    UTF_16 = "UTF-16"
    UTF_16BE = "UTF-16BE"
    UTF_16LE = "UTF-16LE"
    UTF_32 = "UTF-32"
    UTF_32BE = "UTF-32BE"
    UTF_32LE = "UTF-32LE"
    UTF_7 = "UTF-7"
    UTF_8 = "UTF-8"
    VISCII = "VISCII"
    VISCII1_1_1 = "VISCII1.1-1"
    WCHAR_T = "WCHAR_T"
    WINBALTRIM = "WINBALTRIM"
    WINDOWS_1250 = "WINDOWS-1250"
    WINDOWS_1251 = "WINDOWS-1251"
    WINDOWS_1252 = "WINDOWS-1252"
    WINDOWS_1253 = "WINDOWS-1253"
    WINDOWS_1254 = "WINDOWS-1254"
    WINDOWS_1255 = "WINDOWS-1255"
    WINDOWS_1256 = "WINDOWS-1256"
    WINDOWS_1257 = "WINDOWS-1257"
    WINDOWS_1258 = "WINDOWS-1258"
    WINDOWS_874 = "WINDOWS-874"
    WINDOWS_936 = "WINDOWS-936"
    X0201 = "X0201"
    X0208 = "X0208"
    X0212 = "X0212"
